@@ -22,12 +22,13 @@ GBIFtableCleanup <- function(GBIFtable) {
     GBIFtable["name"] <- NA
     GBIFtable["longitude"] <- NA
     GBIFtable["latitude"] <- NA
+    GBIFtable["coordinateUncertaintyInMeters"] <- NA
     GBIFtable["day"] <- NA
     GBIFtable["month"] <- NA
     GBIFtable["year"] <- NA
-    GBIFtable["Dataset"] <- NA
-    GBIFtable["DatasetKey"] <- NA
-    GBIFtable["DataService"] <- NA
+    GBIFtable["datasetName"] <- NA
+    GBIFtable["datasetKey"] <- NA
+    GBIFtable["dataService"] <- NA
     GBIFtable <- as.data.frame(as.list(GBIFtable))
     return(GBIFtable)
   } else if (nrow(GBIFtable) == 0) {
@@ -35,12 +36,13 @@ GBIFtableCleanup <- function(GBIFtable) {
     GBIFtable["name"] <- NA
     GBIFtable["longitude"] <- NA
     GBIFtable["latitude"] <- NA
+    GBIFtable["coordinateUncertaintyInMeters"] <- NA
     GBIFtable["day"] <- NA
     GBIFtable["month"] <- NA
     GBIFtable["year"] <- NA
-    GBIFtable["Dataset"] <- NA
-    GBIFtable["DatasetKey"] <- NA
-    GBIFtable["DataService"] <- NA
+    GBIFtable["datasetName"] <- NA
+    GBIFtable["datasetKey"] <- NA
+    GBIFtable["dataService"] <- NA
     GBIFtable <- as.data.frame(as.list(GBIFtable))
     return(GBIFtable)
   } else {
@@ -49,24 +51,26 @@ GBIFtableCleanup <- function(GBIFtable) {
       GBIFtable["name"] <- as.factor(unlist(GBIFtable["name"]))
       GBIFtable["longitude"] <- as.numeric(unlist(GBIFtable["longitude"]))
       GBIFtable["latitude"] <- as.numeric(unlist(GBIFtable["latitude"]))
+      GBIFtable["coordinateUncertaintyInMeters"] <- as.numeric(unlist(GBIFtable["coordinateUncertaintyInMeters"]))
       GBIFtable["day"] <- as.integer(unlist(GBIFtable["day"]))
       GBIFtable["month"] <- as.integer(unlist(GBIFtable["month"]))
       GBIFtable["year"] <- as.integer(unlist(GBIFtable["year"]))
-      GBIFtable["Dataset"] <- as.factor(unlist(GBIFtable["Dataset"]))
-      GBIFtable["DatasetKey"] <- as.factor(unlist(GBIFtable["DatasetKey"]))
-      GBIFtable["DataService"] <- as.factor(unlist(GBIFtable["DataService"]))
+      GBIFtable["datasetName"] <- as.factor(unlist(GBIFtable["datasetName"]))
+      GBIFtable["datasetKey"] <- as.factor(unlist(GBIFtable["datasetKey"]))
+      GBIFtable["dataService"] <- as.factor(unlist(GBIFtable["dataService"]))
       return(GBIFtable)
     } else {
       GBIFtable <- NULL
       GBIFtable["name"] <- NA
       GBIFtable["longitude"] <- NA
       GBIFtable["latitude"] <- NA
+      GBIFtable["coordinateUncertaintyInMeters"] <- NA
       GBIFtable["day"] <- NA
       GBIFtable["month"] <- NA
       GBIFtable["year"] <- NA
-      GBIFtable["Dataset"] <- NA
-      GBIFtable["DatasetKey"] <- NA
-      GBIFtable["DataService"] <- NA
+      GBIFtable["datasetName"] <- NA
+      GBIFtable["datasetKey"] <- NA
+      GBIFtable["dataService"] <- NA
       GBIFtable <- as.data.frame(as.list(GBIFtable))
       return(GBIFtable)
     }
